@@ -1,8 +1,7 @@
 package Compress::LZ4Frame;
 # ABSTRACT: Compression package using the lz4frame library
-$Compress::LZ4Frame::VERSION = '0.011_001'; # TRIAL
-
-$Compress::LZ4Frame::VERSION = '0.011001';use 5.010_001;
+$Compress::LZ4Frame::VERSION = '0.001';
+use 5.010_001;
 use strict;
 use warnings;
 use vars qw($VERSION);
@@ -12,7 +11,7 @@ use Exporter qw(import);
 
 __PACKAGE__->load($VERSION);
 
-our @EXPORT_OK = qw(compress compress_checksum decompress looks_like_lz4frame);
+our @EXPORT_OK = qw(compress compress_checksum decompress);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 1;
@@ -29,7 +28,7 @@ Compress::LZ4Frame - Compression package using the lz4frame library
 
 =head1 VERSION
 
-version 0.011_001
+version 0.001
 
 =head1 SYNOPSIS
 
@@ -37,16 +36,12 @@ version 0.011_001
 
     my @data = map { rand } (1..50000);
     my $packed = pack('d*', @data);
-
+    
     # compress
     my $compressed = compress($packed);
     # or with checksum
     my $compressed = compress_checksum($packed);
 
-    # check data
-    looks_like_lz4frame($compressed);   # some true value
-    looks_like_lz4frame($packed);       # some false value
-
     # decompress
     my $decompressed = decompress($compressed);
 
@@ -72,25 +67,11 @@ which will be checked by decompress.
 
 Decompresses the given data.
 
-=head2 looks_like_lz4frame
-
-    $okay = looks_like_lz4frame($data)
-
-Checks the given data for a valid LZ4 frame.
-
 =head1 COMPATIBILITY
 
 The format of the compressed data is incompatible to that of L<Compress::LZ4>, thus they are not interoperable.
 Other than that this package should be compatible to every program/library working with the official lz4frame format.
 
-=head1 ACKNOWLEDGEMENTS
-
-Many thanks goes to the following individuals who helped improve C<Compress-LZ4Frame>:
-
-I<Yann Collet> for creating the LZ4 library and the lz4frame format, also for helping me fix nasty bugs.
-
-I<A. Sinan Ünür> for nmake support.
-
 =head1 SEE ALSO
 
 =over 4
@@ -111,7 +92,7 @@ Felix Bytow <felix.bytow@autinity.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by afr-consulting GmbH.
+This software is copyright (c) 2015 by afr-consulting GmbH.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
